{-# LANGUAGE EmptyDataDecls #-}
module OpenCascade.GP.Types
( Pnt
, Pnt2d
, Ax1
, Ax2
, Ax2d
, Ax3
, Dir
, Dir2d
, Vec
, Vec2d
, Trsf
, Trsf2d
, GTrsf
, XYZ
) where

data Pnt
data Pnt2d
data Ax1
data Ax2
data Ax2d
data Ax3
data Dir
data Dir2d
data Vec
data Vec2d
data Trsf
data Trsf2d
data GTrsf
data XYZ
